@@ -1,10 +1,7 @@
 use asyncgit::AsyncNotification;
 use crossbeam_channel::{unbounded, Receiver};
 use crossterm::event::{self, Event};
-use std::{
-    thread::sleep,
-    time::{Duration, Instant},
-};
+use std::time::{Duration, Instant};
 
 ///
 #[derive(Clone, Copy)]
@@ -17,13 +14,11 @@ pub enum QueueEvent {
 static MAX_POLL_DURATION: Duration = Duration::from_secs(2);
 static MIN_POLL_DURATION: Duration = Duration::from_millis(5);
 static MAX_BATCHING_DURATION: Duration = Duration::from_millis(25);
-static TICK_DURATION: Duration = Duration::from_secs(5);
 
 ///
 pub fn start_polling_thread() -> Receiver<Vec<QueueEvent>> {
     let (tx, rx) = unbounded();
 
-    let tx1 = tx.clone();
     rayon_core::spawn(move || {
         let mut last_send = Instant::now();
         let mut batch = Vec::new();
@@ -41,18 +36,13 @@ pub fn start_polling_thread() -> Receiver<Vec<QueueEvent>> {
             if !batch.is_empty()
                 && last_send.elapsed() > MAX_BATCHING_DURATION
             {
-                tx1.send(batch).unwrap();
+                tx.send(batch).expect("send input event failed");
                 batch = Vec::new();
                 last_send = Instant::now();
             }
         }
     });
 
-    rayon_core::spawn(move || loop {
-        tx.send(vec![QueueEvent::Tick]).unwrap();
-        sleep(TICK_DURATION);
-    });
-
     rx
 }
 
